@@ -35,6 +35,7 @@ THE SOFTWARE.
 #include <sys/socket.h>
 #include <sys/uio.h>
 #include <netinet/in.h>
+#include <netinet/ip.h>
 #include <arpa/inet.h>
 #include <net/if.h>
 
@@ -380,9 +381,6 @@ main(int argc, char **argv)
 
 #define SWITCH(new)                                                     \
     do {                                                                \
-        assert(!!config_data == (new == STATE_BOUND ||                  \
-                                 new == STATE_RENEWING_UNICAST ||       \
-                                 new == STATE_RENEWING));               \
         debugf(2, "Switching to state %d.\n", new);                     \
         state = new;                                                    \
         if(state == STATE_IDLE || state == STATE_BOUND)                 \
@@ -969,6 +967,7 @@ ahcp_socket(int port)
     int s, rc;
     int saved_errno;
     int one = 1, zero = 0;
+    const int ds = 0xc0;        /* CS6 - Network Control */
 
     s = socket(PF_INET6, SOCK_DGRAM, 0);
     if(s < 0)
@@ -995,6 +994,15 @@ ahcp_socket(int port)
         perror("setsockopt(IPV6_V6ONLY)");
 #endif
 
+#ifdef IPV6_TCLASS
+    rc = setsockopt(s, IPPROTO_IPV6, IPV6_TCLASS, &ds, sizeof(ds));
+#else
+    rc = -1;
+    errno = ENOSYS;
+#endif
+    if (rc < 0)
+        perror("setsockopt(IPV6_TCLASS)");
+
     rc = fcntl(s, F_GETFD, 0);
     if(rc < 0)
         goto fail;
