@@ -29,8 +29,10 @@ THE SOFTWARE.
 #include <time.h>
 #include <errno.h>
 #include <sys/types.h>
+#include <sys/uio.h>
 #include <dirent.h>
 #include <sys/socket.h>
+#include <netinet/in.h>
 #include <arpa/inet.h>
 
 #include "ahcpd.h"
